@@ -51,7 +51,7 @@ optional arguments:
   -s SERVER_ADDR        server address
   -p SERVER_PORT        server port
   -b LOCAL_ADDR         local binding address, default is 127.0.0.1
-  -s LOCAL_PORT         local port
+  -l LOCAL_PORT         local port
   -k PASSWORD           password
   -s METHOD             encryption method, for example, aes-256-cfb
   -c CONFIG             path to config file
